@@ -420,7 +420,9 @@ class ModelView(BaseModelView):
                 if len(p.columns) > 1:
                     filtered = tools.filter_foreign_columns(self.model.__table__, p.columns)
 
-                    if len(filtered) > 1:
+                    if len(filtered) == 0:
+                        continue
+                    elif len(filtered) > 1:
                         warnings.warn('Can not convert multiple-column properties (%s.%s)' % (self.model, p.key))
                         continue
 
@@ -594,7 +596,7 @@ class ModelView(BaseModelView):
                     if column.foreign_keys or column.primary_key:
                         continue
 
-                    visible_name = '%s / %s' % (self.get_column_name(attr.prop.table.name),
+                    visible_name = '%s / %s' % (self.get_column_name(attr.prop.target.name),
                                                 self.get_column_name(p.key))
 
                     type_name = type(column.type).__name__
